package com.gic.download.utils.log;

import com.alibaba.fastjson.JSON;
import com.gic.download.utils.ExecutorPoolSingleton;
import com.gic.enterprise.context.RequestContext;
import com.gic.enterprise.utils.UserDetail;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.log.api.dto.SystemSetLogDTO;
import com.gic.log.api.service.LogApiService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

@Component
public class LogUtils {
    private static final Logger LOGGER = LogManager.getLogger(LogUtils.class);

    private static LogApiService logApiService;

    @Autowired
    public void setLogApiService(LogApiService logApiService) {
        LogUtils.logApiService = logApiService;
    }

    /**
     * 添加日志
     * @Title: createLog 
     * @Description:
      * @author guojuxing
     * @param content 操作内容
     * @param operationObject  操作对象
     * @return  void 
      */
    public static void createLog(String content, String operationObject) {
        UserDetail userDetail = UserDetailUtils.getUserDetail();
        SystemSetLogDTO logDTO = new SystemSetLogDTO();
        //操作时间
        logDTO.setLogTime(new Date());
        logDTO.setCreateTime(new Date());
        //操作人
        logDTO.setUserId(Long.valueOf(userDetail.getUserInfo().getUserId()));
        logDTO.setUserName(userDetail.getUserInfo().getUserName());
        //操作内容
        logDTO.setContent(operationObject + "-" + content);
        //todo 暂时用这个
        logDTO.setInterfaceName(operationObject + "-" + content);
        //操作模块
        String moduleMenuName = (String) RequestContext.getContext().getRequest().getAttribute("moduleMenuName");
        Integer moduleMenuId = (Integer) RequestContext.getContext().getRequest().getAttribute("moduleMenuId");
        if (moduleMenuId != null) {
            logDTO.setRelationId(Long.valueOf(moduleMenuId));
            logDTO.setProject(moduleMenuName);
        } else {
            LOGGER.info("操作模块数据有误");
        }
        //操作对象

        //账号（手机号）？

        logDTO.setEnterpriesId(Long.valueOf(userDetail.getEnterpriseInfo().getEnterpriseId()));
        logDTO.setEnterpriseName(userDetail.getEnterpriseInfo().getEnterpriseName());
        ExecutorPoolSingleton.getInstance().executeTask(new Runnable() {
            @Override
            public void run() {
                LOGGER.info("添加日志了，恭喜发财。{}", JSON.toJSONString(logDTO));
                logApiService.saveSystemSetLog(logDTO);
            }
        });
    }
    /**
     * 添加日志
     * @Title: createLog 
     * @Description:
      * @author guojuxing
     * @param content 操作内容
     * @param operationObject  操作对象
     * @return  void 
      */
    public static void createLog(String content, String operationObject, String username, Integer enterpriseId, String enterpriseName) {
        UserDetail userDetail = UserDetailUtils.getUserDetail();
        SystemSetLogDTO logDTO = new SystemSetLogDTO();
        //操作时间
        logDTO.setLogTime(new Date());
        logDTO.setCreateTime(new Date());
        //操作人
//        logDTO.setUserId(Long.valueOf(userDetail.getUserInfo().getUserId()));
        logDTO.setUserName(username);
        //操作内容
        logDTO.setContent(content);
        //操作模块
//        String moduleMenuName = (String) RequestContext.getContext().getRequest().getAttribute("moduleMenuName");
//        Integer moduleMenuId = (Integer) RequestContext.getContext().getRequest().getAttribute("moduleMenuId");
//        if (moduleMenuId != null) {
//            logDTO.setRelationId(Long.valueOf(moduleMenuId));
//        } else {
//            LOGGER.info("操作模块数据有误");
//        }
        //操作对象

        //账号（手机号）？

        logDTO.setEnterpriesId(Long.valueOf(enterpriseId));
        logDTO.setEnterpriseName(enterpriseName);
        ExecutorPoolSingleton.getInstance().executeTask(new Runnable() {
            @Override
            public void run() {
                LOGGER.info("添加日志了，恭喜发财。{}", JSON.toJSONString(logDTO));
                logApiService.saveSystemSetLog(logDTO);
            }
        });
    }
}
